## II. Elementary Rules Of Usage

### Rule 1. Form the possessive singular of nouns by adding 's.

Follow this rule whatever the final consonant. Thus write,

Charles's friend

Burns's poems

the witch's malice

This is the usage of the United States Government Printing Office and of the Oxford University Press.

Exceptions are the possessive of ancient proper names ending in *-es* and *-is*, the possessive *Jesus'*, and such forms as *for conscience' sake*, *for righteousness' sake*. But such forms as *Achilles' heel*, *Moses' laws*, *Isis' temple* are commonly replaced by

the heel of Achilles

the laws of Moses

the temple of Isis

The pronominal possessives *hers*, *its*, *theirs*, *yours*, and *oneself* have no apostrophe.

### Rule 2. In a series of three or more terms with a single conjunction, use a comma after each term except the last.

Thus write,

red, white, and blue

gold, silver, or copper

He opened the letter, read it, and made a note of its contents.

This is also the usage of the Government Printing Office and of the Oxford University Press.

In the names of business firms the last comma is omitted, as,

Brown, Shipley & Co.

### Rule 3. Enclose parenthetic expressions between commas.

The best way to see a country, unless you are pressed for time, is to travel on foot.

This rule is difficult to apply; it is frequently hard to decide whether a single word, such as *however*, or a brief phrase, is or is not parenthetic. If the interruption to the flow of the sentence is but slight, the writer may safely omit the commas. But whether the interruption be slight or considerable, he must never insert one comma and omit the other. Such punctuation as

Marjorie's husband, Colonel Nelson paid us a visit yesterday,

or

My brother you will be pleased to hear, is now in perfect health,

is indefensible.

If a parenthetic expression is preceded by a conjunction, place the first comma before the conjunction, not after it.

He saw us coming, and unaware that we had learned of his treachery, greeted us with a smile.

Always to be regarded as parenthetic and to be enclosed between commas (or, at the end of the sentence, between comma and period) are the following:

\(1\) the year, when forming part of a date, and the day of the month, when following the day of the week:

February to July, 1916.

April 6, 1917.

Monday, November 11, 1918.

\(2\) the abbreviations *etc.* and *jr.*

\(3\) non-restrictive relative clauses, that is, those which do not serve to identify or define the antecedent noun, and similar clauses introduced by conjunctions indicating time or place.

The audience, which had at first been indifferent, became more and more interested.

In this sentence the clause introduced by *which* does not serve to tell which of several possible audiences is meant; what audience is in question is supposed to be already known. The clause adds, parenthetically, a statement supplementing that in the main clause. The sentence is virtually a combination of two statements which might have been made independently:

The audience had at first been indifferent. It became more and more interested.

Compare the restrictive relative clause, not set off by commas, in the sentence,

The candidate who best meets these requirements will obtain the place.

Here the clause introduced by *who* does serve to tell which of several possible candidates is meant; the sentence cannot be split up into two independent statements.

The difference in punctuation in the two sentences following is based on the same principle:

Nether Stowey, where Coleridge wrote The Rime of the Ancient Mariner, is a few miles from Bridgewater.

The day will come when you will admit your mistake.

Nether Stowey is completely identified by its name; the statement about Coleridge is therefore supplementary and parenthetic. The *day* spoken of is identified only by the dependent clause, which is therefore restrictive.

Similar in principle to the enclosing of parenthetic expressions between commas is the setting off by commas of phrases or dependent clauses preceding or following the main clause of a sentence.

Partly by hard fighting, partly by diplomatic skill, they enlarged their dominions to the east, and rose to royal rank with the possession of Sicily, exchanged afterwards for Sardinia.

Other illustrations may be found in sentences quoted under Rules 4, 5, 6, 7, 16, and 18.

The writer should be careful not to set off independent clauses by commas: see under Rule 5.

### Rule 4. Place a comma before a conjunction introducing a co-ordinate clause.

The early records of the city have disappeared, and the story of its first years can no longer be reconstructed.

The situation is perilous, but there is still one chance of escape.

Sentences of this type, isolated from their context, may seem to be in need of rewriting. As they make complete sense when the comma is reached, the second clause has the appearance of an afterthought. Further, *and* is the least specific of connectives. Used between independent clauses, it indicates only that a relation exists between them without defining that relation. In the example above, the relation is that of cause and result. The two sentences might be rewritten:

As the early records of the city have disappeared, the story of its first years can no longer be reconstructed.

Although the situation is perilous, there is still one chance of escape.

Or the subordinate clauses might be replaced by phrases:

Owing to the disappearance of the early records of the city, the story of its first years can no longer be reconstructed.

In this perilous situation, there is still one chance of escape.

But a writer may err by making his sentences too uniformly compact and periodic, and an occasional loose sentence prevents the style from becoming too formal and gives the reader a certain relief. Consequently, loose sentences of the type first quoted are common in easy, unstudied writing. But a writer should be careful not to construct too many of his sentences after this pattern (see Rule 14).

Two-part sentences of which the second member is introduced by *as* (in the sense of *because*), *for*, *or*, *nor*, and *while* (in the sense of *and at the same time*) likewise require a comma before the conjunction.

If the second member is introduced by an adverb, a semicolon, not a comma, is required (see Rule 5). The connectives *so* and *yet* may be used either as adverbs or as conjunctions, accordingly as the second clause is felt to be co-ordinate or subordinate; consequently either mark of punctuation may be justified. But these uses of *so* (equivalent to *accordingly* or to *so that*) are somewhat colloquial and should, as a rule, be avoided in writing. A simple correction, usually serviceable, is to omit the word *so* and begin the first clause with *as* or *since*:

| Original | Revision |
| --- | --- |
| I had never been in the place before; so I had difficulty in finding my way about. | As I had never been in the place before, I had difficulty in finding my way about. |

If a dependent clause, or an introductory phrase requiring to be set off by a comma, precedes the second independent clause, no comma is needed after the conjunction.

The situation is perilous, but if we are prepared to act promptly, there is still one chance of escape.

When the subject is the same for both clauses and is expressed only once, a comma is required if the connective is *but*. If the connective is *and*, the comma should be omitted if the relation between the two statements is close or immediate.

I have heard his arguments, but am still unconvinced.

He has had several years' experience and is thoroughly competent.

### Rule 5. Do not join independent clauses by a comma.

If two or more clauses, grammatically complete and not joined by a conjunction, are to form a single compound sentence, the proper mark of punctuation is a semicolon.

Stevenson's romances are entertaining; they are full of exciting adventures.

It is nearly half past five; we cannot reach town before dark.

It is of course equally correct to write the above as two sentences each, replacing the semicolons by periods.

Stevenson's romances are entertaining. They are full of exciting adventures.

It is nearly half past five. We cannot reach town before dark.

If a conjunction is inserted the proper mark is a comma (Rule 4).

Stevenson's romances are entertaining, for they are full of exciting adventures.

It is nearly half past five, and we cannot reach town before dark.

A comparison of the three forms given above will show clearly the advantage of the first. It is, at least in the examples given, better than the second form, because it suggests the close relationship between the two statements in a way that the second does not attempt, and better than the third, because briefer and therefore more forcible. Indeed it may be said that this simple method of indicating relationship between statements is one of the most useful devices of composition. The relationship, as above, is commonly one of cause or of consequence.

Note that if the second clause is preceded by an adverb, such as *accordingly*, *besides*, *then*, *therefore*, or *thus*, and not by a conjunction, the semicolon is still required.

Two exceptions to the rule may be admitted. If the clauses are very short, and are alike in form, a comma is usually permissible:

Man proposes, God disposes.

The gate swung apart, the bridge fell, the portcullis was drawn up.

Note that in these examples the relation is not one of cause or consequence. Also in the colloquial form of expression,

I hardly knew him, he was so changed,

a comma, not a semicolon, is required. But this form of expression is inappropriate in writing, except in the dialogue of a story or play, or perhaps in a familiar letter.

### Rule 6. Do not break sentences in two.

In other words, do not use periods for commas.

I met them on a Cunard liner several years ago. Coming home from Liverpool to New York.

He was an interesting talker. A man who had traveled all over the world and lived in half a dozen countries.

In both these examples, the first period should be replaced by a comma, and the following word begun with a small letter.

It is permissible to make an emphatic word or expression serve the purpose of a sentence and to punctuate it accordingly:

Again and again he called out. No reply.

The writer must, however, be certain that the emphasis is warranted, and that he will not be suspected of a mere blunder in syntax or in punctuation.

Rules 3, 4, 5, and 6 cover the most important principles in the punctuation of ordinary sentences; they should be so thoroughly mastered that their application becomes second nature.

### Rule 7. A participial phrase at the beginning of a sentence must refer to the grammatical subject.

Walking slowly down the road, he saw a woman accompanied by two children.

The word *walking* refers to the subject of the sentence, not to the woman. If the writer wishes to make it refer to the woman, he must recast the sentence:

He saw a woman accompanied by two children, walking slowly down the road.

Participial phrases preceded by a conjunction or by a preposition, nouns in apposition, adjectives, and adjective phrases come under the same rule if they begin the sentence.

| Original | Revision |
| --- | --- |
| On arriving in Chicago, his friends met him at the station. | When he arrived (or, On his arrival) in Chicago, his friends met him at the station. |
| A soldier of proved valor, they entrusted him with the defence of the city. | A soldier of proved valor, he was entrusted with the defence of the city. |
| Young and inexperienced, the task seemed easy to me. | Young and inexperienced, I thought the task easy. |
| Without a friend to counsel him, the temptation proved irresistible. | Without a friend to counsel him, he found the temptation irresistible. |

Sentences violating this rule are often ludicrous.

Being in a dilapidated condition, I was able to buy the house very cheap.

Wondering irresolutely what to do next, the clock struck twelve.
